# Genomics Extension for SQLite

**("GenomicSQLite")**

This [SQLite3 loadable extension](https://www.sqlite.org/loadext.html) adds features supporting applications in genome bioinformatics:

* genomic range indexing for overlap queries & joins
* streaming storage compression (also available [standalone](https://github.com/mlin/sqlite_zstd_vfs))
* pre-tuned settings for "big data"

Notice: this project is not associated with the SQLite developers.

https://github.com/mlin/GenomicSQLite
